#
# spec file for package maven-assembly-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-assembly-plugin
Version:        3.6.0
Release:        2.2
Summary:        Maven Assembly Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-assembly-plugin/
Source0:        https://downloads.apache.org/maven/plugins/%{name}-%{version}-source-release.zip
Patch0:         aggregated-timestamp.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.shared:maven-common-artifact-filters)
BuildRequires:  mvn(org.apache.maven.shared:maven-filtering)
BuildRequires:  mvn(org.apache.maven:maven-archiver)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.codehaus.plexus:plexus-archiver)
BuildRequires:  mvn(org.codehaus.plexus:plexus-interpolation)
BuildRequires:  mvn(org.codehaus.plexus:plexus-io)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.aether:aether-api)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildArch:      noarch

%description
A Maven plugin to create archives of your project's sources, classes,
dependencies etc. from flexible assembly descriptors.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package provides %{summary}.

%prep
%setup -q
%patch0 -p1

%pom_remove_dep jaxen:jaxen

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Thu Sep 14 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * aggregated-timestamp.patch
    + use SOURCE_DATE_EPOCH for the timestamp of aggregated
    properties
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 3.6.0
- Changes of 3.6.0
  * Bugs
    + MASSEMBLY-843: finalName as readonly parameter makes common
    usecases very complicated
    + MASSEMBLY-965: Symbolic links get copied with absolute path
    + MASSEMBLY-977: Warning if using Maven 3.9.1
    + MASSEMBLY-986: Minimal default Manifest configuration of jar
    archiver should be respected
  * New Feature
    + MASSEMBLY-973: Support Zstandard compression format
  * Improvements
    + MASSEMBLY-989: in RB mode, apply 022 umask to ignore
    environment group write umask
    + MASSEMBLY-990: add system requirements history
  * Task
    + MASSEMBLY-974: Drop deprecated repository element
    + MASSEMBLY-983: Support running build on Java 20
    + MASSEMBLY-984: Refresh download page
    + MASSEMBLY-985: Cleanup declared dependencies
    + MASSEMBLY-988: Avoid using deprecated methods of
    plexus-archiver
- Changes of 3.5.0
  * Bug
    + MASSEMBLY-941: file permissions removed during assembly:single
    since 3.2.0
- Changes of 3.4.2
  * Bug
    + MASSEMBLY-969: Excludes filtering in 3.4.0 and 3.4.1 differs
    from 3.3.0
  * Task
    + MASSEMBLY-949: Examples should refer to https instead of http
- Changes of 3.4.1
  * Bug
    + MASSEMBLY-964: Error build with shared assemblies
- Changes of 3.4.0
  * Bug
    + MASSEMBLY-955: dependencySet includes filter with classifier
    breaks include of artifacts without classifier
  * Task
    + MASSEMBLY-945: Speed improvements
    + MASSEMBLY-954: Update plugin (requires Maven 3.2.5+)
    + MASSEMBLY-956: assembly plugin resolves too much, even plugins
    used to build dependencies
    + MASSEMBLY-957: Deprecate the repository element in assembly
    decriptor
    + MASSEMBLY-959: Upgrade to Java 8, drop unused dependencies
* Tue Dec 29 2020 Wang Jun <jgwang@suse.com>
- Update to version 3.3.0
  * Add Documentation for duplicateBehaviour option
  * Add ASF Jira badge
  * Add GitHub Informations.
  * Allow to override UID/GID for files stored in TAR
  * Apply try-with-resources
  * Update AbstractAssemblyMojo.java
  * Use HTTPS instead of HTTP to resolve dependencies
  * Fix broken links (MPIR 3)
  * Fix checkstyle issue
  * Fix Javadoc error
  * Support concatenation of files
  * Multi-release JAR files aren't handled correctly
  * Tighten language
  * Replace TestFileManager with TemporaryFolder
  * Replace ArtifactMock using EasyMock with mock(Artifact.class)
    using Mockito
  * Replace EasyMock with Mockito
  * Remove invalid relativePath from parent section
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.2.0
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Add Group: line for documentation.
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-assembly-plugin 3.1.0
